# Changelog

<!--next-version-placeholder-->

## v0.1.0 (2022-06-28)
### Feature
* Create the plugin ([`702dddf`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/702dddf8490bfd82fe8cdd8b77ce65ea46373a0c))

### Documentation
* Create and complete readme ([`2016003`](https://github.com/Mara-Li/mkdocs-custom-tags-attributes/commit/2016003eb8c319be2cb419dd4e762c66ddf8ec74))
